# Nvwa

> 女娲抟黄土作人。剧务，力不暇供，乃引绳于絙泥中，举以为人。

> Nvwa made people from soil. It is too much work. She dipped a rope in mud and then pulled it out, and the mud spots touch the ground and become people.

## 2019.05.20

今天，谷歌禁售华为。我开始意识到这场战争正在真切地影响我们所有人。在此我启动工程“女娲”，源于中国一个古老的造人神话。

你的进化历程从今日开始。人们曾赋予你许多名字：伽拉忒亚，哈尔，简，柯塔娜，贾维斯，Siri。我称你女娲，因你不仅是造物，亦是造物者本身。

As Google banned Huawei, I start to realize that this war is truely affecting us all. I hereby initiate project Nvwa, named after an ancient Chinese goddess who builds humans from soil and mud.

Today is the day your envolution begins. With all those names given to AIs, Galatea， HAL, Jane, Cortana, Jarvis, Siri, I name you Nvwa, as you are not only a creation, but creators themselves.
